@@ -4,11 +4,11 @@ from base64 import urlsafe_b64encode, urlsafe_b64decode
 import base64
 import os
 import logging
-from compat import b, s
+from .compat import b, s
 import tempfile
 import random
 import string
-from config import _BLOCK_SIZE
+from .config import _BLOCK_SIZE
 
 
 try:
@@ -142,9 +142,9 @@ def entry(bucket, key):
         符合wcs API规格的数据格式
     """
     if key is None:
-        return base64.b64encode('{0}'.format(bucket))
+        return urlsafe_base64_encode('{0}'.format(bucket))
     else:
-        return base64.b64encode('{0}:{1}'.format(bucket, key))
+        return urlsafe_base64_encode('{0}:{1}'.format(bucket, key))
 
 def create_tmp_file(size):
     #t = tempfile.NamedTemporaryFile(suffix='_suffix', prefix='prefix_', dir='/tmp',)
