@@ -2,6 +2,8 @@
 import os
 import requests
 import sys
+from requests_toolbelt import MultipartEncoder
+
 from wcs.commons.config import PUT_URL
 from wcs.commons.http import _post
 from wcs.commons.util import urlsafe_base64_decode
@@ -17,14 +19,22 @@ class RegUpload(object):
     def reg_upload(self, filepath):
         puturl = "{0}/{1}/{2}".format(PUT_URL,"file","upload")
         if os.path.exists(filepath) and os.path.isfile(filepath):
-            f = open(filepath, 'rb')
-            file = {'file': f}
-            headers = {"Accept":"*/*"}
+            try:
+                f = open(filepath, 'rb')
+            except IOError as err:
+                debug('IO Exception:%s' % err)
+                return -1, err
+
+            self.fileds["file"] = ('filename', f, 'text/plain')
+
+            encoder = MultipartEncoder(self.fileds)
+            headers = {"Content-Type":encoder.content_type}
+
             try:
                 debug('File %s upload start!' % filepath)
-                r = requests.post(url=puturl, headers=headers, data=self.fileds, files=file, verify=True)
+                r = requests.post(url=puturl, headers=headers, data=encoder, verify=True)
             except Exception as e:
-                error('Exception:%s' % e)
+                debug('Post Exception:%s' % e)
                 f.close()
                 return -1, e
             f.close()
